@@ -26,7 +26,10 @@ var pipeCmd = &cobra.Command{
 			options.Silence = sf
 		}
 		printing.Banner(options)
+		tMethod := options.Method
+		options.Method = "Pipe Mode"
 		printing.Summary(options, "Stdin (pipeline)")
+		options.Method = tMethod
 		var targets []string
 		mutex := &sync.Mutex{}
 		options.Mutex = mutex
@@ -90,6 +93,9 @@ var pipeCmd = &cobra.Command{
 					}
 				}()
 			}
+			if options.Format == "json" {
+				printing.DalLog("PRINT", "[", options)
+			}
 			for k, v := range t {
 				temp := model.MassJob{
 					Name: k,
@@ -99,6 +105,9 @@ var pipeCmd = &cobra.Command{
 			}
 			close(tasks)
 			wg.Wait()
+			if options.Format == "json" {
+				printing.DalLog("PRINT", "{}]", options)
+			}
 			if (!options.NoSpinner || !options.Silence) && !sf {
 				options.SpinnerObject.Stop()
 			}
@@ -115,6 +124,9 @@ var pipeCmd = &cobra.Command{
 				}
 				options.SpinnerObject.Start()
 			}
+			if options.Format == "json" {
+				printing.DalLog("PRINT", "[", options)
+			}
 			for i := range targets {
 				options.NowURL = i + 1
 				_, _ = scanning.Scan(targets[i], options, strconv.Itoa(i))
@@ -126,6 +138,9 @@ var pipeCmd = &cobra.Command{
 					mutex.Unlock()
 				}
 			}
+			if options.Format == "json" {
+				printing.DalLog("PRINT", "{}]", options)
+			}
 			if (!options.NoSpinner || !options.Silence) && !sf {
 				options.SpinnerObject.Stop()
 			}
