@@ -15,14 +15,24 @@ type PoC struct {
 	Payload    string `json:"payload"`
 	Evidence   string `json:"evidence"`
 	CWE        string `json:"cwe"`
-	Severity  string `json:"severity"`
+	Severity   string `json:"severity"`
 }
 
 // Result is struct for library and cli application
 type Result struct {
 	Logs      []string      `json:"logs"`
 	PoCs      []PoC         `json:"pocs"`
+	Params    []ParamResult `json:"params"`
 	Duration  time.Duration `json:"duration"`
 	StartTime time.Time     `json:"start_time"`
 	EndTime   time.Time     `json:"end_time"`
 }
+
+type ParamResult struct {
+	Name           string
+	Type           string
+	Reflected      bool
+	ReflectedPoint string
+	ReflectedCode  string
+	Chars          []string
+}
