@@ -18,6 +18,7 @@ import (
 	"github.com/hahwul/dalfox/v2/pkg/model"
 	"github.com/hahwul/dalfox/v2/pkg/optimization"
 	"github.com/hahwul/dalfox/v2/pkg/printing"
+	"github.com/hahwul/dalfox/v2/pkg/report"
 	"github.com/hahwul/dalfox/v2/pkg/verification"
 	voltFile "github.com/hahwul/volt/file"
 )
@@ -127,10 +128,6 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 		printing.DalLog("SYSTEM", "Valid target [ code:"+strconv.Itoa(tres.StatusCode)+" / size:"+strconv.Itoa(len(body))+" ]", options)
 	}
 
-	if options.Format == "json" {
-		printing.DalLog("PRINT", "[", options)
-	}
-
 	var wait sync.WaitGroup
 	task := 3
 	sa := "SA: ✓ "
@@ -225,13 +222,33 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 	}
 
 	for k, v := range params {
+		temp := model.ParamResult{
+			Name:      k,
+			Reflected: false,
+		}
+
 		if len(v) != 0 {
 			code, vv := v[len(v)-1], v[:len(v)-1]
 			char := strings.Join(vv, "  ")
 			//x, a = a[len(a)-1], a[:len(a)-1]
 			printing.DalLog("INFO", "Reflected "+k+" param => "+char, options)
 			printing.DalLog("CODE", code, options)
+			arr := strings.Split(char, "  ")
+			for _, value := range arr {
+				if strings.Contains(value, "PTYPE:") {
+					splitedValue := strings.Split(value, " ")
+					temp.Type = splitedValue[1]
+				} else if strings.Contains(value, "Injected:") {
+					splitedValue := strings.Split(value, " ")
+					temp.ReflectedPoint = splitedValue[1]
+				} else {
+					temp.Chars = append(temp.Chars, value)
+				}
+			}
+			temp.ReflectedCode = code
+			temp.Reflected = true
 		}
+		scanResult.Params = append(scanResult.Params, temp)
 	}
 
 	if !options.OnlyDiscovery {
@@ -301,15 +318,16 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 										ptype = GetPType(av)
 									}
 								}
-								// Add plain XSS Query
-								tq, tm := optimization.MakeRequestQuery(target, k, customPayload, "inHTML"+ptype, "toAppend", "NaN", options)
-								query[tq] = tm
-								// Add URL encoded XSS Query
-								etq, etm := optimization.MakeRequestQuery(target, k, customPayload, "inHTML"+ptype, "toAppend", "urlEncode", options)
-								query[etq] = etm
-								// Add HTML Encoded XSS Query
-								htq, htm := optimization.MakeRequestQuery(target, k, customPayload, "inHTML"+ptype, "toAppend", "htmlEncode", options)
-								query[htq] = htm
+								encoders := []string{
+									"NaN",
+									"urlEncode",
+									"urlDoubleEncode",
+									"htmlEncode",
+								}
+								for _, encoder := range encoders {
+									tq, tm := optimization.MakeRequestQuery(target, k, customPayload, "inHTML"+ptype, "toAppend", encoder, options)
+									query[tq] = tm
+								}
 							}
 						}
 					}
@@ -344,15 +362,16 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 					cpArr = append(cpArr, v)
 					arc := optimization.SetPayloadValue(getCommonPayload(), options)
 					for _, avv := range arc {
-						// Add plain XSS Query
-						tq, tm := optimization.MakeRequestQuery(target, v, avv, "inHTML-URL", "toAppend", "NaN", options)
-						query[tq] = tm
-						// Add URL encoded XSS Query
-						etq, etm := optimization.MakeRequestQuery(target, v, avv, "inHTML-URL", "toAppend", "urlEncode", options)
-						query[etq] = etm
-						// Add HTML Encoded XSS Query
-						htq, htm := optimization.MakeRequestQuery(target, v, avv, "inHTML-URL", "toAppend", "htmlEncode", options)
-						query[htq] = htm
+						encoders := []string{
+							"NaN",
+							"urlEncode",
+							"urlDoubleEncode",
+							"htmlEncode",
+						}
+						for _, encoder := range encoders {
+							tq, tm := optimization.MakeRequestQuery(target, v, avv, "inHTML-URL", "toAppend", encoder, options)
+							query[tq] = tm
+						}
 					}
 				}
 			}
@@ -362,15 +381,16 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 					cpdArr = append(cpdArr, v)
 					arc := optimization.SetPayloadValue(getCommonPayload(), options)
 					for _, avv := range arc {
-						// Add plain XSS Query
-						tq, tm := optimization.MakeRequestQuery(target, v, avv, "inHTML-FORM", "toAppend", "NaN", options)
-						query[tq] = tm
-						// Add URL encoded XSS Query
-						etq, etm := optimization.MakeRequestQuery(target, v, avv, "inHTML-FORM", "toAppend", "urlEncode", options)
-						query[etq] = etm
-						// Add HTML Encoded XSS Query
-						htq, htm := optimization.MakeRequestQuery(target, v, avv, "inHTML-FORM", "toAppend", "htmlEncode", options)
-						query[htq] = htm
+						encoders := []string{
+							"NaN",
+							"urlEncode",
+							"urlDoubleEncode",
+							"htmlEncode",
+						}
+						for _, encoder := range encoders {
+							tq, tm := optimization.MakeRequestQuery(target, v, avv, "inHTML-FORM", "toAppend", encoder, options)
+							query[tq] = tm
+						}
 					}
 				}
 			}
@@ -449,10 +469,30 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 							// Injected pattern
 							injectedPoint := strings.Split(av, "/")
 							injectedPoint = injectedPoint[1:]
+							injectedChars := params[k][:len(params[k])-1]
 							for _, ip := range injectedPoint {
 								var arr []string
 								if strings.Contains(ip, "inJS") {
-									arr = optimization.SetPayloadValue(getInJsPayload(ip), options)
+									checkInJS := false
+									if strings.Contains(ip, "double") {
+										for _, injectedChar := range injectedChars {
+											if strings.Contains(injectedChar, "\"") {
+												checkInJS = true
+											}
+										}
+									}
+									if strings.Contains(ip, "single") {
+										for _, injectedChar := range injectedChars {
+											if strings.Contains(injectedChar, "'") {
+												checkInJS = true
+											}
+										}
+									}
+									if checkInJS {
+										arr = optimization.SetPayloadValue(getInJsPayload(ip), options)
+									} else {
+										arr = optimization.SetPayloadValue(getInJsBreakScriptPayload(ip), options)
+									}
 								}
 								if strings.Contains(ip, "inHTML") {
 									arr = optimization.SetPayloadValue(getHTMLPayload(ip), options)
@@ -462,15 +502,16 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 								}
 								for _, avv := range arr {
 									if optimization.Optimization(avv, badchars) {
-										// Add plain XSS Query
-										tq, tm := optimization.MakeRequestQuery(target, k, avv, ip+ptype, "toAppend", "NaN", options)
-										query[tq] = tm
-										// Add URL Encoded XSS Query
-										etq, etm := optimization.MakeRequestQuery(target, k, avv, ip+ptype, "toAppend", "urlEncode", options)
-										query[etq] = etm
-										// Add HTML Encoded XSS Query
-										htq, htm := optimization.MakeRequestQuery(target, k, avv, ip+ptype, "toAppend", "htmlEncode", options)
-										query[htq] = htm
+										encoders := []string{
+											"NaN",
+											"urlEncode",
+											"urlDoubleEncode",
+											"htmlEncode",
+										}
+										for _, encoder := range encoders {
+											tq, tm := optimization.MakeRequestQuery(target, k, avv, ip+ptype, "toAppend", encoder, options)
+											query[tq] = tm
+										}
 									}
 								}
 							}
@@ -481,15 +522,16 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 					for _, avv := range arc {
 						if !containsFromArray(cpArr, k) {
 							if optimization.Optimization(avv, badchars) {
-								// Add plain XSS Query
-								tq, tm := optimization.MakeRequestQuery(target, k, avv, "inHTML"+ptype, "toAppend", "NaN", options)
-								query[tq] = tm
-								// Add URL encoded XSS Query
-								etq, etm := optimization.MakeRequestQuery(target, k, avv, "inHTML"+ptype, "toAppend", "urlEncode", options)
-								query[etq] = etm
-								// Add HTML Encoded XSS Query
-								htq, htm := optimization.MakeRequestQuery(target, k, avv, "inHTML"+ptype, "toAppend", "htmlEncode", options)
-								query[htq] = htm
+								encoders := []string{
+									"NaN",
+									"urlEncode",
+									"urlDoubleEncode",
+									"htmlEncode",
+								}
+								for _, encoder := range encoders {
+									tq, tm := optimization.MakeRequestQuery(target, k, avv, "inHTML"+ptype, "toAppend", encoder, options)
+									query[tq] = tm
+								}
 							}
 						}
 					}
@@ -534,17 +576,17 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 					for _, bpayload := range bpayloads {
 						// Add plain XSS Query
 						bp := strings.Replace(bpayload, "CALLBACKURL", bcallback, 10)
-						tq, tm := optimization.MakeRequestQuery(target, k, bp, "toBlind"+ptype, "toAppend", "NaN", options)
-						tm["payload"] = "toBlind"
-						query[tq] = tm
-						// Add URL encoded XSS Query
-						etq, etm := optimization.MakeRequestQuery(target, k, bp, "toBlind"+ptype, "toAppend", "urlEncode", options)
-						etm["payload"] = "toBlind"
-						query[etq] = etm
-						// Add HTML Encoded XSS Query
-						htq, htm := optimization.MakeRequestQuery(target, k, bp, "toBlind"+ptype, "toAppend", "htmlEncode", options)
-						htm["payload"] = "toBlind"
-						query[htq] = htm
+						encoders := []string{
+							"NaN",
+							"urlEncode",
+							"urlDoubleEncode",
+							"htmlEncode",
+						}
+						for _, encoder := range encoders {
+							tq, tm := optimization.MakeRequestQuery(target, k, bp, "toBlind"+ptype, "toAppend", encoder, options)
+							tm["payload"] = "toBlind"
+							query[tq] = tm
+						}
 					}
 				}
 			}
@@ -576,15 +618,16 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 											ptype = GetPType(av)
 										}
 									}
-									// Add plain XSS Query
-									tq, tm := optimization.MakeRequestQuery(target, k, remotePayload, "inHTML"+ptype, "toAppend", "NaN", options)
-									query[tq] = tm
-									// Add URL encoded XSS Query
-									etq, etm := optimization.MakeRequestQuery(target, k, remotePayload, "inHTML"+ptype, "toAppend", "urlEncode", options)
-									query[etq] = etm
-									// Add HTML Encoded XSS Query
-									htq, htm := optimization.MakeRequestQuery(target, k, remotePayload, "inHTML"+ptype, "toAppend", "htmlEncode", options)
-									query[htq] = htm
+									encoders := []string{
+										"NaN",
+										"urlEncode",
+										"urlDoubleEncode",
+										"htmlEncode",
+									}
+									for _, encoder := range encoders {
+										tq, tm := optimization.MakeRequestQuery(target, k, remotePayload, "inHTML"+ptype, "toAppend", encoder, options)
+										query[tq] = tm
+									}
 								}
 							}
 						}
@@ -1017,9 +1060,7 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 			s.Stop()
 		}
 	}
-	if options.Format == "json" {
-		printing.DalLog("PRINT", "{}]", options)
-	}
+
 	options.Scan[sid] = scanObject
 	scanResult.EndTime = time.Now()
 	scanResult.Duration = scanResult.EndTime.Sub(scanResult.StartTime)
@@ -1036,5 +1077,16 @@ func Scan(target string, options model.Options, sid string) (model.Result, error
 		}
 		printing.DalLog("SYSTEM-M", "[duration: "+scanResult.Duration.String()+"][issues: "+strconv.Itoa(len(scanResult.PoCs))+"] Finish Scan!", options)
 	}
+	if options.ReportBool {
+		printing.DalLog("SYSTEM-M", "Report\n", options)
+		if options.ReportFormat == "json" {
+			jobject, err := json.MarshalIndent(scanResult, "", " ")
+			if err == nil {
+				fmt.Println(string(jobject))
+			}
+		} else {
+			report.GenerateReport(scanResult, options)
+		}
+	}
 	return scanResult, nil
 }
